@@ -2,21 +2,12 @@ package Test::PlugAuth::Plugin;
 
 use strict;
 use warnings;
+use Test2::Plugin::FauxHomeDir;
 
 # ABSTRACT: Private package for Test::PlugAUth::Plugin::* modules
-our $VERSION = '0.35'; # VERSION
+our $VERSION = '0.36'; # VERSION
 
 
-BEGIN {
-  $ENV{LOG_LEVEL} = "ERROR";
-
-  unless($INC{'File/HomeDir/Test.pm'}) 
-  {
-    require File::HomeDir::Test;
-    File::HomeDir::Test->import;
-  }
-}
-
 1;
 
 __END__
@@ -31,7 +22,7 @@ Test::PlugAuth::Plugin - Private package for Test::PlugAUth::Plugin::* modules
 
 =head1 VERSION
 
-version 0.35
+version 0.36
 
 =head1 SEE ALSO
 
